@@ -440,7 +440,7 @@ class NeuralSpaceNLP(Component):
         if not self.model_id and self.can_train_new_model:
             training_response = start_training(self.project_id, self.language)
 
-            self.model_id = training_response[KEY_DATA][KEY_MODEL_ID]
+            self.model_id = training_response[KEY_DATA][0]
             self.component_config[KEY_MODEL_ID] = self.model_id
 
             # Will wait till the training process ends
